@@ -1,4 +1,3 @@
-#!/usr/bin/env python3.11
 """
        Name:
 DESCRIPTION:
@@ -6,7 +5,6 @@ DESCRIPTION:
     LICENSE: GNU AFFERO GENERAL PUBLIC LICENSE Version 3
 """
 from importlib.metadata import version as get_version
-import logging as log
 from xdg_base_dirs import xdg_config_home
 from os import getenv, path, uname
 from pathlib import Path
@@ -29,12 +27,12 @@ SYSINFO = uname()
 OS = (SYSINFO.sysname, SYSINFO.machine)
 
 # step config is different per OS
-STEPS = ['dot_files','packages','font_setup','neovim_setup','group_setup']
+STEPS = ['dot_files','packages','cron','font_setup','neovim_setup','group_setup']
 if OS[0] == 'Darwin':
     STEPS.append('sudo_setup')
 
 # package manager config is different per OS
-PKG_MNGRS = ['brew','pip3.11']
+PKG_MNGRS = ['brew','pip3.12','pip3.11','pipx']
 if OS[0] == 'Linux':
     PKG_MNGRS.extend(['apt','snap','flatpak'])
 
@@ -42,6 +40,9 @@ if OS[0] == 'Linux':
 default_dotfiles = ("https://raw.githubusercontent.com/jessebot/dot_files/"
                     "main/.config/onboardme/")
 
+if OS[0] == 'Linux' and OS[1] == 'aarch64':
+    default_dotfiles = ("https://raw.githubusercontent.com/jessebot/dot_files/"
+                        "docker-arm64-only/.config/onboardme/")
 
 def load_cfg(config_file='config.yml') -> dict:
     """
@@ -61,3 +62,6 @@ def load_cfg(config_file='config.yml') -> dict:
 
 
 USR_CONFIG_FILE = load_cfg()
+
+DEFAULT_PKG_GROUPS = USR_CONFIG_FILE['package']['groups']['default']
+OPT_PKG_GROUPS = USR_CONFIG_FILE['package']['groups']['optional']
