@@ -13,27 +13,46 @@ from .console_logging import print_panel, print_msg
 from .subproc import subproc
 
 
-XDG_CONFIG_GIT_PATH = path.join(XDG_CONFIG_DIR, 'git/config')
+xdg_git_config_dir = path.join(XDG_CONFIG_DIR, 'git')
+Path(xdg_git_config_dir).mkdir(exist_ok=True)
+XDG_GIT_CONFIG = path.join(xdg_git_config_dir, 'config')
 
 
-def setup_dot_files(OS='Linux', overwrite=False,
-                    git_url="https://github.com/jessebot/dot_files.git",
-                    branch="main") -> None:
+def setup_dot_files(OS='Linux',
+                    overwrite=False,
+                    git_url="https://git.smallhack.org/jessebot/dot_files.git",
+                    branch="main",
+                    dot_files_cfg_dir=f"{XDG_CONFIG_DIR}/dot_files") -> None:
     """
     note on how we're doing things, seperate dot files repo:
     https://probablerobot.net/2021/05/keeping-'live'-dotfiles-in-a-git-repo/
+
+
     """
-    git_dir = path.join(HOME_DIR, '.git_dot_files')
-    # create ~/.git_dot_files if it does not exist
-    Path(git_dir).mkdir(exist_ok=True)
-    chdir(git_dir)
-    opts = {'quiet': True, 'cwd': git_dir}
+    # create dot_files_cfg_dir if it doesn't exist/don't complain if it does
+    # defaults to ~/.config/dot_files
+    Path(dot_files_cfg_dir).mkdir(parents=True, exist_ok=True)
+    chdir(dot_files_cfg_dir)
+    opts = {'quiet': True, 'cwd': dot_files_cfg_dir}
 
-    # global: use main as default branch, always push up new remote branch
-    git_raw = "https://raw.githubusercontent.com/jessebot/dot_files/main"
+    if git_url:
+        if "github.com" in git_url:
+            # get just the owner/repo_name like jessebot/dot_files
+            user_repo = "/".join(git_url.split("/")[-2:]).replace(".git", "")
+        else:
+            # get just the owner/repo_name like jessebot/dot_files
+            user_repo = "/".join(git_url.split("/")[-2:]).replace(".git", "")
+            # should cover cases such as codeberg and selfhosted forgejo/gitea
+            git_domain = git_url.split(user_repo)[0]
 
-    cmds = [f'curl {git_raw}/.config/git/config -o {XDG_CONFIG_GIT_PATH}',
-            f'git --git-dir={git_dir} --work-tree={HOME_DIR} init',
+    if "github.com" in git_url:
+        git_raw = f"https://raw.githubusercontent.com/{user_repo}/{branch}"
+    else:
+        # should cover cases such as codeberg and selfhosted forgejo/gitea
+        git_raw = f"{git_domain}/{user_repo}/raw/branch/{branch}"
+
+    cmds = [f'curl {git_raw}/.config/git/config -o {XDG_GIT_CONFIG}',
+            f'git --git-dir={dot_files_cfg_dir} --work-tree={HOME_DIR} init',
             'git config status.showUntrackedFiles no']
     subproc(cmds, spinner=False, **opts)
 
@@ -41,6 +60,11 @@ def setup_dot_files(OS='Linux', overwrite=False,
     cmds = [f"git remote add origin {git_url}"]
     subproc(cmds, error_ok=True, spinner=False, **opts)
 
+    # create ~/.config/.git to get git status while editing config files
+    if not path.isfile(f"{XDG_CONFIG_DIR}/.git"):
+        with open(f"{XDG_CONFIG_DIR}/.git", "w") as config_git_config:
+            config_git_config.write(f"gitdir: {dot_files_cfg_dir}")
+
     if overwrite:
         # WARN: this command will overwrite local files with remote files
         reset_cmd = f"git reset --hard origin/{branch}"
