@@ -8,11 +8,11 @@ import logging as log
 from rich.prompt import Confirm
 
 # custom libs
-from .constants import OS, USR_CONFIG_FILE
+from .constants import OS, USR_CONFIG_FILE, DEFAULT_PKG_GROUPS, HOME_DIR
 from .console_logging import print_panel
 
 
-def check_os_support():
+def check_os_support() -> None:
     """
     verify we're on a supported OS and ask to quit if not.
     """
@@ -33,7 +33,9 @@ def check_os_support():
                     "[cornflower_blue]Compatibility Check")
 
 
-def process_steps(steps: list, firewall=False, browser=False) -> list:
+def process_steps(steps: list,
+                  firewall: bool = False,
+                  browser: bool = False) -> list:
     """
     process which steps to run for which OS, which steps the user passed in,
     and then make sure dependent steps are always run.
@@ -48,13 +50,21 @@ def process_steps(steps: list, firewall=False, browser=False) -> list:
         if 'neovim_setup' in steps_list and 'dot_files' not in steps_list:
             steps_list.append('dot_files')
 
+        # need cron files to setup crontabs
+        if 'cron' in steps_list and 'dot_files' not in steps_list:
+            steps_list.append('dot_files')
+
         if firewall and 'Linux' in OS:
             # currently don't have a great firewall on macOS, sans lulu
             steps_list.append('firewall_setup')
 
     removed_duplicates = set(steps_list)
     steps = list(removed_duplicates)
-    default_order = ['dot_files', 'packages', 'font_setup', 'neovim_setup']
+    default_order = ['dot_files',
+                     'packages',
+                     'cron',
+                     'font_setup',
+                     'neovim_setup']
     if OS[0] == 'Linux':
         default_order.append('group_setup')
     else:
@@ -70,9 +80,15 @@ def sort_pkgmngrs(package_managers_list: list) -> list:
     e.g. apt installs snap and flatpak, so niether can be run until apt is run
 
     Takes list of package manager str and reorders them be (if they exist):
-       ['brew', 'pip3.11', 'apt', 'snap', 'flatpak']
+       ['brew', 'pip3.12', 'pip3.11', 'pipx', 'apt', 'snap', 'flatpak']
     """
-    pkg_mngr_default_order = ['brew', 'pip3.11', 'apt', 'snap', 'flatpak']
+    pkg_mngr_default_order = ['brew',
+                              'pip3.12',
+                              'pip3.11',
+                              'pipx',
+                              'apt',
+                              'snap',
+                              'flatpak']
 
     # Rearrange list by other list order Using list comprehension
     return [ele for ele in pkg_mngr_default_order if ele in package_managers_list]
@@ -87,7 +103,7 @@ def fill_in_defaults(defaults: dict, user_config: dict,
     for key, value in user_config.items():
         # we have to iterate through the entire config file, and who knows how
         # many levels there are, so we use recursion of this function
-        if type(value) is dict:
+        if isinstance(value, dict):
             result_config = fill_in_defaults(defaults[key], user_config[key],
                                              always_prefer_default)
             user_config[key] = result_config
@@ -98,9 +114,16 @@ def fill_in_defaults(defaults: dict, user_config: dict,
     return user_config
 
 
-def process_configs(overwrite: bool, repo: str, git_branch: str, 
-                    pkg_mngrs: list, pkg_groups: list, firewall: bool,
-                    remote_host: str, steps: list, log_file: str,
+def process_configs(overwrite: bool,
+                    repo: str,
+                    git_branch: str,
+                    git_config_dir: str,
+                    pkg_mngrs: list,
+                    pkg_groups: list,
+                    firewall: bool,
+                    remote_host: str,
+                    steps: list,
+                    log_file: str,
                     log_level: str) -> dict:
     """
     process the config in ~/.config/onboardme/config.yml if it exists,
@@ -109,9 +132,11 @@ def process_configs(overwrite: bool, repo: str, git_branch: str,
     """
     if remote_host:
         firewall = True
-        if type(remote_host) is str:
+        if isinstance(remote_host, str):
             remote_host = [remote_host]
 
+    if "~" in git_config_dir:
+        git_config_dir = git_config_dir.replace("~", HOME_DIR)
 
     cli_dict = {'package': {'managers': {OS[0]: pkg_mngrs},
                             'groups': pkg_groups},
@@ -120,17 +145,26 @@ def process_configs(overwrite: bool, repo: str, git_branch: str,
                 'firewall': firewall,
                 'steps': {OS[0]: steps},
                 'dot_files': {'overwrite': overwrite,
-                              'git_url': repo, 'git_branch': git_branch}}
+                              'git_url': repo,
+                              'git_branch': git_branch,
+                              'git_config_dir': git_config_dir}}
 
     log.debug(f"cli_dict is:\n{cli_dict}\n")
 
     if OS[0] == 'Darwin':
-        USR_CONFIG_FILE['package']['managers'].pop('Linux')
-        USR_CONFIG_FILE['steps'].pop('Linux')
+        try:
+            USR_CONFIG_FILE['package']['managers'].pop('Linux')
+            USR_CONFIG_FILE['steps'].pop('Linux')
+        except KeyError:
+            pass
     else:
-        USR_CONFIG_FILE['package']['managers'].pop('Darwin')
-        USR_CONFIG_FILE['steps'].pop('Darwin')
+        try:
+            USR_CONFIG_FILE['package']['managers'].pop('Darwin')
+            USR_CONFIG_FILE['steps'].pop('Darwin')
+        except KeyError:
+            pass
 
+    USR_CONFIG_FILE['package']['groups'] = DEFAULT_PKG_GROUPS
     log.debug(f"🗂 ⚙️  user_config_file: \n{USR_CONFIG_FILE}\n")
     final_defaults = fill_in_defaults(cli_dict, USR_CONFIG_FILE, True)
 
@@ -139,7 +173,7 @@ def process_configs(overwrite: bool, repo: str, git_branch: str,
 
     # make sure the steps are in a valid order
     valid_steps = process_steps(final_defaults['steps'][OS[0]],
-                                final_defaults['remote_hosts'])
+                                final_defaults.get('remote_hosts', False))
     final_defaults['steps'][OS[0]] = valid_steps
 
     # make sure the package managers are in a valid order
