@@ -9,13 +9,15 @@ from rich.panel import Panel
 from rich.table import Table
 from rich.text import Text
 from rich.theme import Theme
+from os import environ
 
 # custom local module
-from .constants import VERSION, STEPS, PKG_MNGRS
+from .constants import (DEFAULT_PKG_GROUPS, OPT_PKG_GROUPS, PKG_MNGRS, STEPS,
+                        VERSION)
 
 
 # this is for creating new help text svgs for the READMEs
-RECORD = False
+RECORD = environ.get("OBM_SCREENSHOT", False)
 
 
 def pretty_choices(default_list: list) -> str:
@@ -33,22 +35,13 @@ def options_help() -> dict:
     """
     Help text for all the options/switches for main()
     """
-    dot_file_url = '[meta]https://github.com/jessebot/dot_files[/meta]'
+    dot_file_url = '[meta]https://git.smallhack.org/jessebot/dot_files[/meta]'
     step_choices = pretty_choices(STEPS)
     pkg_mngr_choices = pretty_choices(PKG_MNGRS)
     logging_choices = pretty_choices(['debug', 'info', 'warn', 'error'])
-    pkg_group_choices = pretty_choices(['default', 'devops', 'gui', 'gaming'])
+    pkg_group_choices = pretty_choices(DEFAULT_PKG_GROUPS + OPT_PKG_GROUPS)
 
     return {
-        'log_level':
-        f'Logging level. {logging_choices}\nDefault: [meta]warn[/meta]',
-
-        'log_file':
-        'Full path to file to log to, if set.',
-
-        'quiet':
-        "unstable. Don't output to stdout. ",
-
         'steps':
         f'[b]Only[/b] run [meta]STEP[/] in the script.\n{step_choices}\nExampl'
         'e: [switch]-s[/] [meta]dot_files[/] [switch]-s[/] [meta]packages',
@@ -59,13 +52,22 @@ def options_help() -> dict:
         'git_branch':
         'Branch to use for the git repo url. Default: main',
 
+        'git_config_dir':
+        'Directory to store the git configuration for your dot files. '
+        'Default: ~/.config/dot_files',
+
+        'generate_screenshot':
+        'Generate a few SVGs for use in the docs and README. Undocumented.',
+
         'overwrite':
         '[b]Overwrites[/b] existing dot files with files from configured '
-        '[option]--git_url[/option] repo.',
+        "[option]--git_url[/option] repo. If you've set overwrite: true in "
+        'your config, then --overwrite on the command line will act as a '
+        'toggle, so it will NOT overwrite your dot files.',
 
         'pkg_managers':
         f'Specific [meta]PKG_MANAGER[/] to run. {pkg_mngr_choices}'
-        '\nExample: [switch]-p[/] [meta]brew[/] [switch]-p[/] [meta]pip3.11',
+        '\nExample: [switch]-p[/] [meta]brew[/] [switch]-p[/] [meta]pip3.12',
 
         'pkg_groups':
         f"Package groups to install.\n{pkg_group_choices}\nExample:"
@@ -81,7 +83,17 @@ def options_help() -> dict:
         'Setup iptables (on [i]linux[/] only).',
 
         'version':
-        f'Print the version of onboardme ({VERSION})'
+        f'Print the version of onboardme ({VERSION})',
+
+        'log_level':
+        f'Logging level. {logging_choices}\nDefault: [meta]warn[/meta]',
+
+        'log_file':
+        'Full path to file to log to, if set.',
+
+        'quiet':
+        "unstable. Don't output to stdout. "
+
     }
 
 
@@ -124,7 +136,7 @@ class RichCommand(click.Command):
                               row_styles=["", "dim"],
                               padding=(1, 1, 0, 0))
 
-        # this used to be self.get_params(ctx)[1:] and I don't know why
+        # this used to be self.get_params(ctx)[1:] to have only one hidden option
         for param in self.get_params(ctx):
 
             if len(param.opts) == 2:
@@ -151,8 +163,8 @@ class RichCommand(click.Command):
 
             options_table.add_row(opt1, opt2, highlighter(help))
 
-        url = (" ♥ docs: [link=https://jessebot.github.io/onboardme/]"
-               "jessebot.github.io/onboardme[/link]")
+        url = (" ♥ docs: [link=https://onboardme.smallhack.org/]"
+               "onboardme.smallhack.org[/link]")
 
         console.print(Panel(options_table,
                             border_style="dim light_steel_blue",
