@@ -37,8 +37,8 @@ def rotate_github_ssh_keys() -> None:
             known_hosts.write(line)
 
 
-def run_preinstall_cmds(cmd_list: list, 
-                        pkg_groups: list, 
+def run_preinstall_cmds(cmd_list: list,
+                        pkg_groups: list,
                         no_upgrade: bool) -> None:
     """
     takes a list of package manager pre-install commands and runs them
@@ -56,12 +56,16 @@ def run_preinstall_cmds(cmd_list: list,
 
     for pre_cmd in pre_cmds:
         if pre_cmd in cmd_list:
-            if pre_cmd == 'update' and 'apt' in pre_cmd:
+            if pre_cmd == 'update' and 'apt' in cmd_list[pre_cmd]:
                 if run_gaming_setup:
                     log.debug("Run gaming commands to update /etc/apt/sources")
                     cmds = ["sudo dpkg --add-architecture i386",
                             f"sudo {PWD}/scripts/update_apt_sources.sh"]
                     subproc(cmds, spinner=False)
+            if pre_cmd == 'upgrade' and 'brew' in cmd_list[pre_cmd]:
+                if OS[0] == 'Darwin':
+                    log.debug("we'll run upgrade --cask for macOS")
+                    subproc(["brew upgrade --cask"])
 
             SPINNER = True
             if 'sudo' in cmd_list[pre_cmd]:
@@ -71,10 +75,10 @@ def run_preinstall_cmds(cmd_list: list,
             sub_header(f"[b]{pre_cmd.title()}[/b] completed.")
 
 
-def run_pkg_mngrs(pkg_mngrs: list, pkg_groups=[], no_upgrade=bool) -> None:
+def run_pkg_mngrs(pkg_mngrs: list, pkg_groups: list = [], no_upgrade: bool = False) -> None:
     """
-    Installs brew and pip3.11 packages. Also apt, snap, and flatpak on Linux.
-    Takes optional variables:
+    Installs brew, pip3.12/pip3.11, and pipx packages on both Debian/Ubuntu/macOS
+    Also apt, snap, and flatpak on Linux. Takes optional variables:
       - pkg_groups: list of optional package groups
       - pkg_mngrs: list of package managers to run
     Returns True
@@ -90,12 +94,12 @@ def run_pkg_mngrs(pkg_mngrs: list, pkg_groups=[], no_upgrade=bool) -> None:
 
         available_pkg_groups = pkg_mngr_dict['packages']
         log.debug(f"pkg groups for {pkg_mngr} are {available_pkg_groups}")
-        
+
         # brew has a special flow because it works on both linux and mac
         if pkg_mngr == 'brew':
             if 'Darwin' in OS:
                 if 'default' in pkg_groups:
-                    if type(pkg_groups) is tuple:
+                    if isinstance(pkg_groups, tuple):
                         pkg_groups = list(pkg_groups)
                     pkg_groups.append("macOS")
 
@@ -119,36 +123,39 @@ def run_pkg_mngrs(pkg_mngrs: list, pkg_groups=[], no_upgrade=bool) -> None:
                 # continues onto the next package manager
                 continue
 
-            if pkg_mngr == 'brew':
-                if 'Darwin' in OS:
-                    # this installs macOS brew taps
-                    install_brew_taps(pkg_mngr_dict['taps']['macOS'])
+            if pkg_mngr == 'flatpak' and not shutil.which('flatpak'):
+                log.warn("flatpak is either not installed, or you need to log out"
+                         "and back in (or reboot) for it to be available. "
+                         "https://flatpak.org/setup/")
+                # continues onto the next package manager
+                continue
+
+            if pkg_mngr == 'pip3.11' and not shutil.which('pip3.11'):
+                log.info("pip3.11 is either not installed, or you need to log out"
+                         "and back in for it to be available.")
+                # continues onto the next package manager
+                continue
 
             # run package manager specific setup if needed: update/upgrade
             run_preinstall_cmds(pkg_cmds, pkg_groups, no_upgrade)
 
             # run the list command for the given package manager
-            list_cmd = pkg_cmds['list']
-            # TODO: figure out a way to make this less hacky
-            if pkg_mngr == 'apt':
-                list_cmd = path.join(PWD, list_cmd)
-            list_pkgs = subproc([list_cmd], quiet=True)
-
-            if list_pkgs:
-                # create list of installed packages to iterate on
-                installed_pkgs = list_pkgs.split()
-            else:
-                installed_pkgs = []
+            installed_pkgs = []
+            list_cmd = pkg_cmds.get('list', None)
+            if list_cmd:
+                list_pkgs = subproc([list_cmd], quiet=True)
+                if list_pkgs:
+                    # create list of installed packages to iterate on
+                    installed_pkgs = list_pkgs.split()
 
             # iterate through package groups for a given package manager
             for pkg_group in pkg_groups:
                 # if package group is in the packages.yaml file
                 if pkg_group in available_pkg_groups:
-                    # used to be for zathura, a document viewer, might delete
+                    # for zathura, a document viewer, might delete
                     # if pkg_group == "macOS":
                     #     # zathura needs some help on macOS
                     #     check_zathura()
-
                     install_pkg_group(pkg_cmds['install'],
                                       available_pkg_groups[pkg_group],
                                       installed_pkgs,
@@ -162,9 +169,9 @@ def run_pkg_mngrs(pkg_mngrs: list, pkg_groups=[], no_upgrade=bool) -> None:
                 sub_header("[b]Cleanup[/b] step Completed.")
 
 
-def install_pkg_group(install_cmd: str, 
+def install_pkg_group(install_cmd: str,
                       pkgs_to_install: list,
-                      installed_pkgs: list, 
+                      installed_pkgs: list,
                       install_env_vars: dict,
                       no_upgrade: bool
                       ) -> None:
@@ -176,6 +183,13 @@ def install_pkg_group(install_cmd: str,
     log.debug(f"Currently installed packages: {installed_pkgs}")
     log.info(f"Packages to install are: {pkgs_to_install}")
 
+    # apt is smart enough to install everything at once correctly
+    if 'apt' in install_cmd:
+        all_packages = ' '.join(pkgs_to_install)
+        subproc([install_cmd + all_packages], quiet=True, env=install_env_vars)
+        return
+
+    # this installs packages one by one
     for pkg in pkgs_to_install:
         if not installed_pkgs:
             log.info(f"{pkg} isn't installed. Installing now...")
@@ -205,31 +219,6 @@ def install_pkg_group(install_cmd: str,
         subproc([install_cmd + pkg], quiet=True, env=install_env_vars)
 
 
-def install_brew_taps(taps: list) -> None:
-    """
-    Checks current brew taps, and then runs brew tap {tap} on any taps that are
-    in a list of git repos from packages.yaml, and aren't already tapped
-    """
-    log.info("Checking current taps.")
-    existing_taps = subproc(["brew tap"])
-    try:
-        current_taps = existing_taps.split('\n')
-    except:
-        current_taps = []
-    
-    log.debug(f"taps list is: {taps}")
-    log.debug(f"Current taps are: {current_taps}")
-
-    # for each tap, complete cmd by prepending `brew tap`
-    for index, tap in enumerate(taps):
-        log.debug(f"index: {index} tap: {tap}")
-        # only brew tap if they don't already exist
-        if tap not in current_taps:
-            subproc(["brew tap " + tap])
-        else:
-            log.info(f"{tap} already installed. Moving on.")
-
-
 # not currently using zathura on macOS, so removing as it's untested
 # def check_zathura() -> None:
 #     """
